==> datadog-api-client-2.2.0-sources.jar: com/datadog/api/client/v2/model/MetricDistinctVolumeType.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v2.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;
import java.io.IOException;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Objects;
import java.util.Set;

/** The metric distinct volume type. */
@JsonSerialize(using = MetricDistinctVolumeType.MetricDistinctVolumeTypeSerializer.class)
public class MetricDistinctVolumeType {

  public static final MetricDistinctVolumeType DISTINCT_METRIC_VOLUMES =
      new MetricDistinctVolumeType("distinct_metric_volumes");

  private static final Set<String> allowedValues =
      new HashSet<String>(Arrays.asList("distinct_metric_volumes"));

  private String value;

  public boolean isValid() {
    return allowedValues.contains(this.value);
  }

  MetricDistinctVolumeType(String value) {
    this.value = value;
  }

  public static class MetricDistinctVolumeTypeSerializer
      extends StdSerializer<MetricDistinctVolumeType> {
    public MetricDistinctVolumeTypeSerializer(Class<MetricDistinctVolumeType> t) {
      super(t);
    }

    public MetricDistinctVolumeTypeSerializer() {
      this(null);
    }

    @Override
    public void serialize(
        MetricDistinctVolumeType value, JsonGenerator jgen, SerializerProvider provider)
        throws IOException, JsonProcessingException {
      jgen.writeObject(value.value);
    }
  }

  @JsonValue
  public String getValue() {
    return this.value;
  }

  public void setValue(String value) {
    this.value = value;
  }

  /** Return true if this MetricDistinctVolumeType object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    return this.value.equals(((MetricDistinctVolumeType) o).value);
  }

  @Override
  public int hashCode() {
    return Objects.hash(value);
  }

  @Override
  public String toString() {
    return String.valueOf(value);
  }

  @JsonCreator
  public static MetricDistinctVolumeType fromValue(String value) {
    return new MetricDistinctVolumeType(value);
  }
}

==> datadog-api-client-2.28.0-sources.jar: com/datadog/api/client/v2/model/MetricDistinctVolumeType.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v2.model;

import com.datadog.api.client.ModelEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;
import java.io.IOException;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

/** The metric distinct volume type. */
@JsonSerialize(using = MetricDistinctVolumeType.MetricDistinctVolumeTypeSerializer.class)
public class MetricDistinctVolumeType extends ModelEnum<String> {

  private static final Set<String> allowedValues =
      new HashSet<String>(Arrays.asList("distinct_metric_volumes"));

  public static final MetricDistinctVolumeType DISTINCT_METRIC_VOLUMES =
      new MetricDistinctVolumeType("distinct_metric_volumes");

  MetricDistinctVolumeType(String value) {
    super(value, allowedValues);
  }

  public static class MetricDistinctVolumeTypeSerializer
      extends StdSerializer<MetricDistinctVolumeType> {
    public MetricDistinctVolumeTypeSerializer(Class<MetricDistinctVolumeType> t) {
      super(t);
    }

    public MetricDistinctVolumeTypeSerializer() {
      this(null);
    }

    @Override
    public void serialize(
        MetricDistinctVolumeType value, JsonGenerator jgen, SerializerProvider provider)
        throws IOException, JsonProcessingException {
      jgen.writeObject(value.value);
    }
  }

  @JsonCreator
  public static MetricDistinctVolumeType fromValue(String value) {
    return new MetricDistinctVolumeType(value);
  }
}
